from setuptools import setup

setup(
    name='just4demo',
    version='0.0.1',
    description='some shit',
    license='MIT',
    packages=['dna'],
    author='Emma Watson',
    author_email='anshulk.it@gmail.com',
    keywords=['example'],
    url='https://github.com/bgse/hellostackoverflow'
)
